@@ -50,7 +50,10 @@ normandy_events = DataSource(
     experiments_column_type="native",
 )
 
-#: DataSource: The telemetry.main ping table.
+#: DataSource: The telemetry_stable.main_v4 ping table.
+#: The main_v4 table is what backs the telemetry.main view.
+#: Referencing the table directly helps us stay under the BigQuery
+#: query complexity budget.
 main = DataSource(
     name="main",
     from_expr="""(
@@ -58,7 +61,7 @@ main = DataSource(
                     *,
                     DATE(submission_timestamp) AS submission_date,
                     environment.experiments
-                FROM `moz-fx-data-shared-prod`.telemetry.main
+                FROM `moz-fx-data-shared-prod`.telemetry_stable.main_v4
             )""",
     experiments_column_type="native",
 )
